@@ -1,4 +1,7 @@
 package WWW::Pusher;
+{
+  $WWW::Pusher::VERSION = '0.0700';
+}
 
 use warnings;
 use strict;
@@ -22,12 +25,10 @@ WWW::Pusher - Interface to the Pusher WebSockets API
 
 =head1 VERSION
 
-Version 0.06
+version 0.0700
 
 =cut
 
-our $VERSION = '0.06';
-
 =head1 SYNOPSIS
 
     use WWW::Pusher;
@@ -63,7 +64,7 @@ sub new
 	die 'Pusher application ID must be defined' unless $args{app_id};
 
 	my $self = {
-		uri	 => URI->new($pusher_defaults->{host} || $args{host}),
+		uri	 => URI->new($args{host} || $pusher_defaults->{host}),
 		lwp	 => LWP::UserAgent->new,
 		debug    => $args{debug} || undef,
 		auth_key => $args{auth_key},
